<?php
/*
Plugin Name: Woocommerce custom tshirt designer
Plugin URI: http://www.solvercircle.com
Description:This plugin is used to design or customize t-shirts by users.  
Version: 2.0.8
Author: SolverCircle
Author URI: http://www.solvercircle.com
*/

if(!defined( 'ABSPATH' )) exit;
define( 'WTD_URL', plugins_url('',__FILE__) );
define( 'WTD_DIR_PATH', plugin_dir_path( __FILE__ ) );

include ( 'includes/tshirt-designer-setup.php' );
include ( 'includes/tshirt-designer-button-display.php' );
include ( 'includes/tshirt-designer-admin-art.php' );
include ( 'includes/tshirt-designer-settings.php' );
include ( 'includes/zipArchive.php' );
    
function wtd_metabox(){
  add_meta_box( 'wtd_metabox_custom', __('Custom Design Option', 'wctd'), 'wtd_design_option_content', 'product', 'normal', 'high' );
}
add_action( 'admin_init', 'wtd_metabox' );
   
function wtd_design_option_content( $product ){
  $custom =                  get_post_custom( $product->ID );
  
  if(isset($custom[ "_wtd_custom_design_checkbox" ][0])){
    $meta_box_check =          $custom[ "_wtd_custom_design_checkbox" ][0];
  }
  else{
    $meta_box_check = FALSE;
  }
  
  $custom_price =            esc_html( get_post_meta( $product->ID,'_wtd_custom_design_extra_price', true ) );
  $custom_back_side_img =    esc_html( get_post_meta( $product->ID,'_wtd_custom_back_image', true ) );
  $upload_base_url =         wtd_get_upload_dir();
?>
  <table id="wtd_custom_meta">
    <tr>
      <td><?php echo _e('Enable design panel at frontend?', 'wctd');?></td>
      <td><input type="checkbox" name="wtd_enable_checkbox" id="wtd_enable_checkbox"  <?php if( $meta_box_check == true ) { ?>checked="checked"<?php } ?>/></td>
    </tr>
    <tr>
      <td><?php echo _e('Extra price for custom design', 'wctd');?></td>
      <td><input type="number" name="wtd_extra_price" id="wtd_extra_price" value="<?php echo $custom_price;?>" /></td>
    </tr>
    <tr>
      <td><?php echo _e('Upload back side image', 'wctd');?></td> 
      <td>
        <input type="text" readonly="true" name="wtd_back_side_image_url" id="wtd_back_side_image_url"/>  
        <span><input id="wtd_back_side_image_uploader" class="button-primary" name="wtd_back_side_image_uploader" type="button" value="<?php echo _e('Browse', 'wctd');?>"/></span>
      </td>
    <?php if( $custom_back_side_img ){?>
        <td><img src="<?php echo $upload_base_url['baseurl'].$custom_back_side_img;?>"/></td>
    <?php }?>
    </tr>
  </table>
<?php
}
	
add_action( 'save_post','wtd_custom_meta_save', 10, 2 );

function wtd_custom_meta_save( $post_id,$product ){
  if ( $product->post_type == 'product' ){
    $get_back_side_image =  esc_html( get_post_meta( $post_id,'_wtd_custom_back_image', true ) );
    
    if( isset($_POST['wtd_extra_price']) && $_POST['wtd_extra_price'] ){
      update_post_meta( $post_id, '_wtd_custom_design_extra_price', $_POST['wtd_extra_price'] );
    }
    else{
      update_post_meta( $post_id, '_wtd_custom_design_extra_price', '' );
    }
    
    if( isset($_POST["wtd_enable_checkbox"]) && $_POST["wtd_enable_checkbox"] ){
      update_post_meta( $post_id, '_wtd_custom_design_checkbox', $_POST["wtd_enable_checkbox"] );
    }
    else{
      update_post_meta( $post_id, '_wtd_custom_design_checkbox', '');
    }
     
    if(isset($_POST["wtd_back_side_image_url"]) && $_POST["wtd_back_side_image_url"]){
      $get_url = $_POST['wtd_back_side_image_url'];
      $upload_base_url = wtd_get_upload_dir();
      $img_url = str_replace( $upload_base_url['baseurl'],'',$get_url );
      update_post_meta( $post_id,  '_wtd_custom_back_image',$img_url );
    }
    else{
      update_post_meta( $post_id,  '_wtd_custom_back_image',$get_back_side_image );
    }
  }
}
    
function wtd_assets_load(){
  wp_enqueue_script( 'jquery');
  wp_enqueue_style(  'wtd-custom-style',plugins_url( '/css/wtd.css', __FILE__  ) );
  wp_enqueue_script( 'wtd-fabric-js-1.2.0', plugins_url( '/js/fabric-1.2.0-all.min.js', __FILE__  ));
  wp_enqueue_script( 'wtd-upload-form', plugins_url( '/js/jquery.form.js', __FILE__  ) );
  wp_enqueue_script( 'wtd-colorpicker-js', plugins_url( '/js/colorpicker/jscolor.js', __FILE__ ));
  wp_enqueue_script( 'wtd-base64-js', plugins_url( '/js/base64.js', __FILE__  ) );
  wp_enqueue_script( 'wtd-custom-js', plugins_url( '/js/wtd.js', __FILE__  ) );
  
  if( !session_id() ){
    session_start();
  }
  
  wctd_load_plugin_textdomain_urls();
}
        
function wtd_add_custom_price( $cart_object ) {
  foreach ( $cart_object->cart_contents as $key => $value ){				
    if( isset( $value['type'] ) && $value['type'] == 'custom'){
      if( isset( $value['total_price'] )){
	  $value['data']->set_price( $value['total_price'] );   
      }
    }
  }
}

function wtd_remove_custom_data( $meta_value ){
  return array(
	  '_qty',
	  '_tax_class',
	  '_product_id',
	  '_variation_id',
	  '_line_subtotal',
	  '_line_subtotal_tax',
	  '_line_total',
	  '_line_tax',
	  'design_id',
	  'design_logo',	
	  'custom_design'		
      );
}

function wtd_add_hidden_field(){
  echo '<div class="wtd_admin_custom_design_main_div">';
  echo '<div class="wtd_admin_custom_design_close_icon"></div>';
  echo '<div class="wtd_admin_custom_design_image_content"></div>';
  echo '</div>';
  echo '<div class="wtd_overlay"></div>';
  echo '<input type="hidden" name="wtd_admin" id="wtd_admin" value="'. WTD_URL .'"/>';
}

function wctd_load_plugin_textdomain_urls() {
  load_plugin_textdomain( 'wctd', false, 'woocommerce-custom-tshirt-designer/languages');
}

add_filter( 'woocommerce_cart_item_thumbnail', 'filter_woocommerce_cart_item_thumbnail', 10, 3 );
function filter_woocommerce_cart_item_thumbnail( $product_get_image, $cart_item, $cart_item_key ) { 
  $img_content = '';

  if(count($cart_item) > 0){
    if(isset($cart_item['type']) && isset($cart_item['design_id']) && $cart_item['type'] == 'custom'){
	$img_content .= '<div class="thumb-img">'. $product_get_image .'</div>';
	$img_content .= '<div id="'. $cart_item['design_id'] .'" class="wct_product_custom_image wct_custom_design_style" style="margin-top:10px;">Design Preview</div>';
    }
    else{
	$img_content = $product_get_image;
    }
  }
		
  return $img_content;
}

add_filter( 'woocommerce_cart_item_name', 'filter_woocommerce_cart_item_name', 10, 3 );
function filter_woocommerce_cart_item_name($name, $cart_item, $cart_item_key){
  $name_content = '';

  if(count($cart_item) > 0){
    if(isset($cart_item['type']) && isset($cart_item['design_id']) && $cart_item['type'] == 'custom'){
	$name_content .= '<div class="product-name">'. $name .'</div>';
	$name_content .= '<div class="custom-design-text">Type: Custom Design Product</div>';
    }
    else{
	$name_content = $name;
    }
  }

  return $name_content;
}


add_action('woocommerce_add_order_item_meta', 'add_order_item_meta', 10, 2);
function add_order_item_meta($item_id, $values) {
  if(isset($values['type'])){
    woocommerce_add_order_item_meta($item_id, 'type', $values['type']);
  }

  if(isset($values['type'])){
    woocommerce_add_order_item_meta($item_id, 'design_id', $values['design_id']);
  }

  if(isset($values['design_logo'])){
    woocommerce_add_order_item_meta($item_id, 'design_logo', $values['design_logo']);
  }

  if(isset($values['custom_design'])){
    woocommerce_add_order_item_meta($item_id, 'custom_design', $values['custom_design']);
  }		
}

function wtd_use_custom_template( $template ){
  $template_slug = basename(rtrim( $template, '.php' ));
  
  
  if( ($template_slug === 'single-product' || $template_slug === 'woocommerce') && isset($_GET['type']) && $_GET['type'] == 'sc_wtd_customize_product'){
    $template = WTD_DIR_PATH . 'includes/tshirt-designer-design-template.php';
  }
  
  return $template;
}


add_action( 'woocommerce_hidden_order_itemmeta','wtd_remove_custom_data' );
add_action( 'woocommerce_before_calculate_totals', 'wtd_add_custom_price' );
add_action( 'init','wtd_assets_load' );
add_action( 'woocommerce_after_shop_loop_item','wtd_button_view_on_products_page' );
add_action( 'wp_footer','wtd_button_display' );
add_action( 'woocommerce_after_add_to_cart_button','wtd_button_view_on_details_page' );
add_action( 'admin_footer','wtd_add_hidden_field');
add_filter( 'template_include', 'wtd_use_custom_template', 99 );
register_activation_hook( __FILE__, 'wtd_plugin_install' );
register_deactivation_hook(__FILE__, 'wtd_plugin_uninstall');